@@ -190,6 +190,7 @@ impl SendTransactionService {
                     Err(RecvTimeoutError::Disconnected) => break,
                     Err(RecvTimeoutError::Timeout) => {}
                     Ok(transaction_info) => {
+                        inc_new_counter_info!("send_transaction_service-recv-tx", 1);
                         let addresses = leader_info.as_ref().map(|leader_info| {
                             leader_info.get_leader_tpus(config.leader_forward_count)
                         });
@@ -210,6 +211,7 @@ impl SendTransactionService {
                             );
                         }
                         if transactions.len() < MAX_TRANSACTION_QUEUE_SIZE {
+                            inc_new_counter_info!("send_transaction_service-insert-tx", 1);
                             transactions.insert(transaction_info.signature, transaction_info);
                         } else {
                             datapoint_warn!("send_transaction_service-queue-overflow");
